=====================
Advanced functions
=====================

Convolution
-----------

.. currentmodule:: sedfitter.convolve

.. autofunction:: convolve_model_dir
.. autofunction:: convolve_model_dir_monochromatic
